
fuelbuddy.showChart = function(chartName, chartTitle, processData, drawChart) {
	$("#chart-area").removeClass("hidden");
	$("#chart-title").html(chartTitle);
	$("#chart-body").html("<i class='fa fa-spinner fa-spin'></i>  Loading ...");
	
	jQuery.get(fuelbuddy.CHARTS_PHP + '?vehid=' + fuelbuddy.current_vehicle_id 
		+ "&startDate="  + fuelbuddy.current_start_date 
		+ "&endDate=" + fuelbuddy.current_end_date
		+ "&chart-name=" + chartName , "", function(chartdata) { 
		
		var processedChartData = processData(chartdata);

		$("#chart-body").empty();
	
		drawChart(processedChartData);
	}, "json")
}

fuelbuddy.showAvgFuelEfficiencyChart = function() {
	fuelbuddy.showChart("avg-fuel-efficiency",
		"Avg Fuel Efficiency",
		function(chartdata) {
			var tmpChartData = [];
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var dayMonthAndYear = ("0"+(d.getDate())).slice(-2) + "/" + ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				tmpChartData.push({
					"date": dayMonthAndYear,
					"consumption": parseFloat(item["consumption"]).toFixed(2)
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Area({
				element: 'chart-body',
				data: chartdata,
				xkey: 'date',
				ykeys: ['consumption'],
				labels: ['consumption'],
				parseTime: false,
				yLabelFormat: function(y) { return y.toFixed(2);}
			});
		}
	);
}
	
	
fuelbuddy.showPricePerVolumeChart = function() {
	fuelbuddy.showChart("avg-price-per-volume",
		"Avg Price",
		function(chartdata) {
			var tmpChartData = [];
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var dayMonthAndYear = ("0"+(d.getDate())).slice(-2) + "/" + ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				tmpChartData.push({
					"date": dayMonthAndYear,
					"cost": parseFloat(item["cost"]).toFixed(2)
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Area({
				element: 'chart-body',
				data: chartdata,
				xkey: 'date',
				ykeys: ['cost'],
				labels: ['cost'],
				parseTime: false,
				yLabelFormat: function(y) { return y.toFixed(2);}
			});
		}
	);
}

fuelbuddy.showDistanceBetweenFillupsChart = function() {
	fuelbuddy.showChart("distance-between-fillups",
		"Distance Between Fill-Ups",
		function(chartdata) {
			var tmpChartData = [];
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var monthAndYear = ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				tmpChartData.push({
					"date": monthAndYear,
					"dist": parseFloat(item["dist"]).toFixed(2)
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			var minDist = 10000;
			var avgDistance = 0;
			$.each(chartdata, function(i, item) {
				avgDistance += parseFloat(item["dist"]);
				avgDistance = avgDistance / (i+1);
				if (parseFloat(item["dist"]) < minDist) {
					minDist = parseFloat(item["dist"]);
				}
			});
			Morris.Area({
			  element: 'chart-body',
			  data: chartdata,
			  xkey: 'date',
			  ykeys: ['dist'],
			  labels: ['dist'],
			  goals: [avgDistance],
			  parseTime: false,
			  ymin: minDist - 50,
			  yLabelFormat: function(y) { return y.toFixed(2);}
			});
		}
	);
}

fuelbuddy.showFillUpsPerMonthChart = function() {
	fuelbuddy.showChart("fill-ups-per-month",
		"Fill-Ups Per Month",
		function(chartdata) {
			var tmpChartData = [];		
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var monthAndYear = ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				tmpChartData.push({
					"date": monthAndYear,
					"fillups": parseInt(item["fillups"])
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Bar({
			  element: 'chart-body',
			  data: chartdata,
			  xkey: 'date',
			  ykeys: ['fillups'],
			  labels: ['Fillups'],
			});
		}
	);
}

fuelbuddy.showTripDistanceByTypeChart = function() {
	fuelbuddy.showChart("trip-dist-by-type",
		"Trip Distance by Type",
		function(chartdata) {
			var tmpChartData = [];		
			$.each(chartdata, function(i, item) {
				tmpChartData.push({
					"dist": item["dist"],
					"type": item["type"]
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Bar({
			  element: 'chart-body',
			  data: chartdata,
			  xkey: 'type',
			  ykeys: ['dist'],
			  labels: ['dist'],
			});
		}
	);
}

fuelbuddy.showTripTaxDeductionByTypeChart = function() {
	fuelbuddy.showChart("trip-tax-deduction-by-type",
		"Trip Tax Deduction by Type",
		function(chartdata) {
			var tmpChartData = [];		
			$.each(chartdata, function(i, item) {
				tmpChartData.push({
					"cost": item["cost"],
					"type": item["type"]
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Bar({
			  element: 'chart-body',
			  data: chartdata,
			  xkey: 'type',
			  ykeys: ['cost'],
			  labels: ['cost'],
			});
		}
	);
}


fuelbuddy.showCostPerDistanceChart = function() {
	$("#fuel-per-distance-chart").empty();
	var tmpChartData = [];
	jQuery.get("db/fuel_cost_per_distance.php" + '?vehid=' + fuelbuddy.current_vehicle_id, "", function(chartdata) { 
		
		var prev_cost = 0;
		var prev_dist = 0;
		var costDistMap = {};
		$.each(chartdata, function(i, item) {
			if (item["partial_fill"] == 1) {
				prev_cost = prev_cost + parseFloat(item["cost"]);
				prev_dist = prev_dist + parseFloat(item["dist"]);
				costDistMap[parseInt(item["date"])] = -1000;                             
			} else {
				curr_cost = prev_cost + parseFloat(item["cost"]);
				curr_dist = prev_dist + parseFloat(item["dist"]);

				prev_cost = 0;
				prev_dist = 0;

				var f = 0;
		 
				if (curr_cost != 0 && curr_dist != 0) {
					f = curr_cost/curr_dist;
				}
            
				costDistMap[parseInt(item["date"])] = f;                            
			}
		});
		console.log(costDistMap);

		// Get all the keys in an array and arrange them in the opposite order
		var dateKeys = [];
		$.each(costDistMap, function(key, value) {
			dateKeys.unshift(key)
		});
		
		// Now do the pfill calculations using the opposite sorted array above for the keys
		var curr_cpd = 0;
		var prev_cpd = 0;
		$.each(dateKeys, function(i, key) {
			curr_cpd = costDistMap[key];
			if (curr_cpd == -1000){
				costDistMap[key] = prev_cpd;
			} else {
				prev_cpd = curr_cpd;
			}
		});
		
		// Convert the map to an array because that's what we need
		$.each(costDistMap, function(key, value) {
			var d = new Date(parseInt(key));
			var dayMonthAndYear = ("0"+(d.getDate())).slice(-2) + "/" + ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
			tmpChartData.push({
				"date": dayMonthAndYear,
				"cost": value
			});
			
		});
		console.log(tmpChartData);
		
		Morris.Area({
		  element: 'fuel-per-distance-chart',
		  data: tmpChartData,
		  xkey: 'date',
		  ykeys: ['cost'],
		  labels: ['cost'],
		  parseTime: false,
		  yLabelFormat: function(y) { return y.toFixed(4);}
		});
		
		
	}, "json")
}
